@@ -3,5 +3,7 @@ var namespaceisc_1_1util_1_1thread =
     [ "CondVar", "de/d20/classisc_1_1util_1_1thread_1_1CondVar.html", "de/d20/classisc_1_1util_1_1thread_1_1CondVar" ],
     [ "Mutex", "d2/d3b/classisc_1_1util_1_1thread_1_1Mutex.html", "d2/d3b/classisc_1_1util_1_1thread_1_1Mutex" ],
     [ "Thread", "db/df4/classisc_1_1util_1_1thread_1_1Thread.html", "db/df4/classisc_1_1util_1_1thread_1_1Thread" ],
-    [ "WatchedThread", "dc/d24/classisc_1_1util_1_1thread_1_1WatchedThread.html", "dc/d24/classisc_1_1util_1_1thread_1_1WatchedThread" ]
+    [ "WatchedThread", "dc/d24/classisc_1_1util_1_1thread_1_1WatchedThread.html", "dc/d24/classisc_1_1util_1_1thread_1_1WatchedThread" ],
+    [ "ThreadPtr", "d0/d0c/namespaceisc_1_1util_1_1thread.html#aae9ca0895893e55c736693b3aaffa3ef", null ],
+    [ "WatchedThreadPtr", "d0/d0c/namespaceisc_1_1util_1_1thread.html#a672dffe010f537b2a19951d6851e9fc2", null ]
 ];
\ No newline at end of file
