@@ -9,5 +9,9 @@ var namespaceisc_1_1perfdhcp =
     [ "PktTransform", "d2/dd2/classisc_1_1perfdhcp_1_1PktTransform.html", null ],
     [ "RateControl", "d2/d6a/classisc_1_1perfdhcp_1_1RateControl.html", "d2/d6a/classisc_1_1perfdhcp_1_1RateControl" ],
     [ "StatsMgr", "d1/d80/classisc_1_1perfdhcp_1_1StatsMgr.html", "d1/d80/classisc_1_1perfdhcp_1_1StatsMgr" ],
-    [ "TestControl", "d8/dc3/classisc_1_1perfdhcp_1_1TestControl.html", "d8/dc3/classisc_1_1perfdhcp_1_1TestControl" ]
+    [ "TestControl", "d8/dc3/classisc_1_1perfdhcp_1_1TestControl.html", "d8/dc3/classisc_1_1perfdhcp_1_1TestControl" ],
+    [ "PerfPkt4Ptr", "d1/d99/namespaceisc_1_1perfdhcp.html#a3fdd9e914a8846e5e333b1517397f2ca", null ],
+    [ "PerfPkt6Ptr", "d1/d99/namespaceisc_1_1perfdhcp.html#ae5b029187fe73f2ce3d33f84fb2dcf9e", null ],
+    [ "late_exit_target_time_", "d1/d99/namespaceisc_1_1perfdhcp.html#a475e4cd6bc39770e87e940cf02c3c956", null ],
+    [ "perfdhcp_config_report", "d1/d99/namespaceisc_1_1perfdhcp.html#a07465ddce91f7df6bff8e424104578ec", null ]
 ];
\ No newline at end of file
