@@ -1,6 +1,6 @@
 var masterload_8h =
 [
-    [ "MasterLoadError", "d3/d5b/classisc_1_1dns_1_1MasterLoadError.html", "d3/d5b/classisc_1_1dns_1_1MasterLoadError" ],
+    [ "isc::dns::MasterLoadError", "d3/d5b/classisc_1_1dns_1_1MasterLoadError.html", "d3/d5b/classisc_1_1dns_1_1MasterLoadError" ],
     [ "MasterLoadCallback", "d4/dd7/masterload_8h.html#a75229acdda8cd740356b601226615826", null ],
     [ "masterLoad", "d4/dd7/masterload_8h.html#a51027e32a02bc9469fbc37ef44fdc77d", null ],
     [ "masterLoad", "d4/dd7/masterload_8h.html#a8fa93573736ad152fe5829edb9108a1e", null ]
