@@ -1,5 +1,5 @@
 var timer__mgr_8h =
 [
-    [ "TimerMgr", "dd/db3/classisc_1_1dhcp_1_1TimerMgr.html", "dd/db3/classisc_1_1dhcp_1_1TimerMgr" ],
+    [ "isc::dhcp::TimerMgr", "dd/db3/classisc_1_1dhcp_1_1TimerMgr.html", "dd/db3/classisc_1_1dhcp_1_1TimerMgr" ],
     [ "TimerMgrPtr", "d5/d3c/timer__mgr_8h.html#a556a4f59a2778e3c4f11a3eb1ee31f95", null ]
 ];
\ No newline at end of file
