@@ -5,5 +5,6 @@ var namespaceisc_1_1util_1_1random =
     [ "QidGenerator", "d9/d0e/classisc_1_1util_1_1random_1_1QidGenerator.html", "d9/d0e/classisc_1_1util_1_1random_1_1QidGenerator" ],
     [ "SumNotOne", "d0/dea/classisc_1_1util_1_1random_1_1SumNotOne.html", "d0/dea/classisc_1_1util_1_1random_1_1SumNotOne" ],
     [ "UniformRandomIntegerGenerator", "d1/db6/classisc_1_1util_1_1random_1_1UniformRandomIntegerGenerator.html", "d1/db6/classisc_1_1util_1_1random_1_1UniformRandomIntegerGenerator" ],
-    [ "WeightedRandomIntegerGenerator", "d1/d65/classisc_1_1util_1_1random_1_1WeightedRandomIntegerGenerator.html", "d1/d65/classisc_1_1util_1_1random_1_1WeightedRandomIntegerGenerator" ]
+    [ "WeightedRandomIntegerGenerator", "d1/d65/classisc_1_1util_1_1random_1_1WeightedRandomIntegerGenerator.html", "d1/d65/classisc_1_1util_1_1random_1_1WeightedRandomIntegerGenerator" ],
+    [ "qid_generator_instance", "d5/dd7/namespaceisc_1_1util_1_1random.html#ae65f0a9b46ec6dafa7b8fc28bcf7f85b", null ]
 ];
\ No newline at end of file
