@@ -1,7 +1,7 @@
 var signal__set_8h =
 [
-    [ "SignalSet", "d5/d67/classisc_1_1util_1_1SignalSet.html", "d5/d67/classisc_1_1util_1_1SignalSet" ],
-    [ "SignalSetError", "d4/d4b/classisc_1_1util_1_1SignalSetError.html", "d4/d4b/classisc_1_1util_1_1SignalSetError" ],
+    [ "isc::util::SignalSet", "d5/d67/classisc_1_1util_1_1SignalSet.html", "d5/d67/classisc_1_1util_1_1SignalSet" ],
+    [ "isc::util::SignalSetError", "d4/d4b/classisc_1_1util_1_1SignalSetError.html", "d4/d4b/classisc_1_1util_1_1SignalSetError" ],
     [ "BoolSignalHandler", "d6/d19/signal__set_8h.html#ae278d648b56af5c48ad37a3780022a03", null ],
     [ "SigIntList", "d6/d19/signal__set_8h.html#a21c223a39aef285255db38a44fa50400", null ],
     [ "SigIntListPtr", "d6/d19/signal__set_8h.html#a384cf66bc94f6b301bbcbde46f9c5655", null ],
