@@ -1,5 +1,5 @@
 var http__header_8h =
 [
-    [ "HttpHeader", "d3/db5/classisc_1_1http_1_1HttpHeader.html", "d3/db5/classisc_1_1http_1_1HttpHeader" ],
+    [ "isc::http::HttpHeader", "d3/db5/classisc_1_1http_1_1HttpHeader.html", "d3/db5/classisc_1_1http_1_1HttpHeader" ],
     [ "HttpHeaderPtr", "d9/d1c/http__header_8h.html#abc1344f8ff3351408f426f628cfb4b55", null ]
 ];
\ No newline at end of file
