@@ -1,6 +1,6 @@
 var stamped__value_8h =
 [
-    [ "StampedValue", "dd/d69/classisc_1_1data_1_1StampedValue.html", "dd/d69/classisc_1_1data_1_1StampedValue" ],
+    [ "isc::data::StampedValue", "dd/d69/classisc_1_1data_1_1StampedValue.html", "dd/d69/classisc_1_1data_1_1StampedValue" ],
     [ "StampedValueCollection", "da/d16/stamped__value_8h.html#a7736458730755937ed9e2379de352d13", null ],
     [ "StampedValuePtr", "da/d16/stamped__value_8h.html#a6c912276497e89f490e6b8eabf586bb7", null ]
 ];
\ No newline at end of file
