@@ -1,7 +1,7 @@
 var option_8h =
 [
-    [ "Option", "d9/dd5/classisc_1_1dhcp_1_1Option.html", "d9/dd5/classisc_1_1dhcp_1_1Option" ],
-    [ "SkipRemainingOptionsError", "dc/df1/classisc_1_1dhcp_1_1SkipRemainingOptionsError.html", "dc/df1/classisc_1_1dhcp_1_1SkipRemainingOptionsError" ],
+    [ "isc::dhcp::Option", "d9/dd5/classisc_1_1dhcp_1_1Option.html", "d9/dd5/classisc_1_1dhcp_1_1Option" ],
+    [ "isc::dhcp::SkipRemainingOptionsError", "dc/df1/classisc_1_1dhcp_1_1SkipRemainingOptionsError.html", "dc/df1/classisc_1_1dhcp_1_1SkipRemainingOptionsError" ],
     [ "OptionBuffer", "db/db8/option_8h.html#aca7e9ef2dc2ba7871a7042ca8438b0f3", null ],
     [ "OptionBufferConstIter", "db/db8/option_8h.html#a47fd5c3a503d201cb53760db4e115669", null ],
     [ "OptionBufferIter", "db/db8/option_8h.html#aa77e8b70869ef95c4e2bc745b230d8e6", null ],
