@@ -1,6 +1,6 @@
 var strutil_8cc =
 [
-    [ "StringSanitizerImpl", "d7/d98/classisc_1_1util_1_1str_1_1StringSanitizerImpl.html", "d7/d98/classisc_1_1util_1_1str_1_1StringSanitizerImpl" ],
+    [ "isc::util::str::StringSanitizerImpl", "d7/d98/classisc_1_1util_1_1str_1_1StringSanitizerImpl.html", "d7/d98/classisc_1_1util_1_1str_1_1StringSanitizerImpl" ],
     [ "decodeColonSeparatedHexString", "dc/d73/strutil_8cc.html#aaec82d24ee9b70456efd98c2b864fc83", null ],
     [ "decodeFormattedHexString", "dc/d73/strutil_8cc.html#a78161daa4e5e2542f6e5338c61d58cc7", null ],
     [ "format", "dc/d73/strutil_8cc.html#a20df524dfbe285e2850fa77f08c88073", null ],
