@@ -1,7 +1,7 @@
 var cfg__option_8h =
 [
-    [ "CfgOption", "d5/d53/classisc_1_1dhcp_1_1CfgOption.html", "d5/d53/classisc_1_1dhcp_1_1CfgOption" ],
-    [ "OptionDescriptor", "de/de7/classisc_1_1dhcp_1_1OptionDescriptor.html", "de/de7/classisc_1_1dhcp_1_1OptionDescriptor" ],
+    [ "isc::dhcp::CfgOption", "d5/d53/classisc_1_1dhcp_1_1CfgOption.html", "d5/d53/classisc_1_1dhcp_1_1CfgOption" ],
+    [ "isc::dhcp::OptionDescriptor", "de/de7/classisc_1_1dhcp_1_1OptionDescriptor.html", "de/de7/classisc_1_1dhcp_1_1OptionDescriptor" ],
     [ "CfgOptionList", "de/d8f/cfg__option_8h.html#afaa269c15e761fbc255d26dd847e6e6f", null ],
     [ "CfgOptionPtr", "de/d8f/cfg__option_8h.html#a2748d431763a2d93d08271f82ce702be", null ],
     [ "ConstCfgOptionPtr", "de/d8f/cfg__option_8h.html#afc6d489471e6c9799c10815d7dc14bf8", null ],
