@@ -1,8 +1,8 @@
 var host_8h =
 [
-    [ "AuthKey", "dd/d41/classisc_1_1dhcp_1_1AuthKey.html", "dd/d41/classisc_1_1dhcp_1_1AuthKey" ],
-    [ "Host", "d7/dd1/classisc_1_1dhcp_1_1Host.html", "d7/dd1/classisc_1_1dhcp_1_1Host" ],
-    [ "IPv6Resrv", "d5/d93/classisc_1_1dhcp_1_1IPv6Resrv.html", "d5/d93/classisc_1_1dhcp_1_1IPv6Resrv" ],
+    [ "isc::dhcp::AuthKey", "dd/d41/classisc_1_1dhcp_1_1AuthKey.html", "dd/d41/classisc_1_1dhcp_1_1AuthKey" ],
+    [ "isc::dhcp::Host", "d7/dd1/classisc_1_1dhcp_1_1Host.html", "d7/dd1/classisc_1_1dhcp_1_1Host" ],
+    [ "isc::dhcp::IPv6Resrv", "d5/d93/classisc_1_1dhcp_1_1IPv6Resrv.html", "d5/d93/classisc_1_1dhcp_1_1IPv6Resrv" ],
     [ "ConstHostCollection", "df/ded/host_8h.html#a3a0590637b8564211bbe4ec04b8764f6", null ],
     [ "ConstHostPtr", "df/ded/host_8h.html#aac9e74ed4d7d676331f7f70593b7bf92", null ],
     [ "HostCollection", "df/ded/host_8h.html#a6d058c67779e9e4f405facd2c6884601", null ],
